@@ -1,11 +1,13 @@
 import logging
-from typing import Any, Callable
+from typing import Any, Callable, Optional, Type, TypeVar
 
 from aws_lambda_powertools.utilities.data_classes import AppSyncResolverEvent
 from aws_lambda_powertools.utilities.typing import LambdaContext
 
 logger = logging.getLogger(__name__)
 
+AppSyncResolverEventT = TypeVar("AppSyncResolverEventT", bound=AppSyncResolverEvent)
+
 
 class AppSyncResolver:
     """
@@ -38,13 +40,13 @@ class AppSyncResolver:
             return str(uuid.uuid4())
     """
 
-    current_event: AppSyncResolverEvent
+    current_event: AppSyncResolverEventT  # type: ignore[valid-type]
     lambda_context: LambdaContext
 
     def __init__(self):
         self._resolvers: dict = {}
 
-    def resolver(self, type_name: str = "*", field_name: str = None):
+    def resolver(self, type_name: str = "*", field_name: Optional[str] = None):
         """Registers the resolver for field_name
 
         Parameters
@@ -62,7 +64,9 @@ class AppSyncResolver:
 
         return register_resolver
 
-    def resolve(self, event: dict, context: LambdaContext) -> Any:
+    def resolve(
+        self, event: dict, context: LambdaContext, data_model: Type[AppSyncResolverEvent] = AppSyncResolverEvent
+    ) -> Any:
         """Resolve field_name
 
         Parameters
@@ -71,6 +75,56 @@ class AppSyncResolver:
             Lambda event
         context : LambdaContext
             Lambda context
+        data_model:
+            Your data data_model to decode AppSync event, by default AppSyncResolverEvent
+
+        Example
+        -------
+
+        ```python
+        from aws_lambda_powertools.event_handler import AppSyncResolver
+        from aws_lambda_powertools.utilities.typing import LambdaContext
+
+        @app.resolver(field_name="createSomething")
+        def create_something(id: str):  # noqa AA03 VNE003
+            return id
+
+        def handler(event, context: LambdaContext):
+            return app.resolve(event, context)
+        ```
+
+        **Bringing custom models**
+
+        ```python
+        from aws_lambda_powertools import Logger, Tracer
+
+        from aws_lambda_powertools.logging import correlation_paths
+        from aws_lambda_powertools.event_handler import AppSyncResolver
+
+        tracer = Tracer(service="sample_resolver")
+        logger = Logger(service="sample_resolver")
+        app = AppSyncResolver()
+
+
+        class MyCustomModel(AppSyncResolverEvent):
+            @property
+            def country_viewer(self) -> str:
+                return self.request_headers.get("cloudfront-viewer-country")
+
+
+        @app.resolver(field_name="listLocations")
+        @app.resolver(field_name="locations")
+        def get_locations(name: str, description: str = ""):
+            if app.current_event.country_viewer == "US":
+                ...
+            return name + description
+
+
+        @logger.inject_lambda_context(correlation_id_path=correlation_paths.APPSYNC_RESOLVER)
+        @tracer.capture_lambda_handler
+        def lambda_handler(event, context):
+            return app.resolve(event, context, data_model=MyCustomModel)
+        ```
 
         Returns
         -------
@@ -82,7 +136,7 @@ class AppSyncResolver:
         ValueError
             If we could not find a field resolver
         """
-        self.current_event = AppSyncResolverEvent(event)
+        self.current_event = data_model(event)
         self.lambda_context = context
         resolver = self._get_resolver(self.current_event.type_name, self.current_event.field_name)
         return resolver(**self.current_event.arguments)
@@ -108,6 +162,8 @@ class AppSyncResolver:
             raise ValueError(f"No resolver found for '{full_name}'")
         return resolver["func"]
 
-    def __call__(self, event, context) -> Any:
+    def __call__(
+        self, event: dict, context: LambdaContext, data_model: Type[AppSyncResolverEvent] = AppSyncResolverEvent
+    ) -> Any:
         """Implicit lambda handler which internally calls `resolve`"""
-        return self.resolve(event, context)
+        return self.resolve(event, context, data_model)
