@@ -4,7 +4,7 @@ import logging
 import os
 import random
 import sys
-from typing import Any, Callable, Dict, Iterable, Optional, TypeVar, Union
+from typing import IO, Any, Callable, Dict, Iterable, Optional, TypeVar, Union
 
 import jmespath
 
@@ -167,11 +167,11 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
 
     def __init__(
         self,
-        service: str = None,
-        level: Union[str, int] = None,
+        service: Optional[str] = None,
+        level: Union[str, int, None] = None,
         child: bool = False,
-        sampling_rate: float = None,
-        stream: sys.stdout = None,
+        sampling_rate: Optional[float] = None,
+        stream: Optional[IO[str]] = None,
         logger_formatter: Optional[PowertoolsFormatter] = None,
         logger_handler: Optional[logging.Handler] = None,
         **kwargs,
@@ -261,10 +261,10 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
 
     def inject_lambda_context(
         self,
-        lambda_handler: Callable[[Dict, Any], Any] = None,
-        log_event: bool = None,
-        correlation_id_path: str = None,
-        clear_state: bool = False,
+        lambda_handler: Optional[Callable[[Dict, Any], Any]] = None,
+        log_event: Optional[bool] = None,
+        correlation_id_path: Optional[str] = None,
+        clear_state: Optional[bool] = False,
     ):
         """Decorator to capture Lambda contextual info and inject into logger
 
@@ -324,7 +324,7 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
             )
 
         log_event = resolve_truthy_env_var_choice(
-            choice=log_event, env=os.getenv(constants.LOGGER_LOG_EVENT_ENV, "false")
+            env=os.getenv(constants.LOGGER_LOG_EVENT_ENV, "false"), choice=log_event
         )
 
         @functools.wraps(lambda_handler)
@@ -363,7 +363,7 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
     @property
     def registered_formatter(self) -> Optional[PowertoolsFormatter]:
         """Convenience property to access logger formatter"""
-        return self.registered_handler.formatter
+        return self.registered_handler.formatter  # type: ignore
 
     def structure_logs(self, append: bool = False, **keys):
         """Sets logging formatting to JSON.
@@ -384,19 +384,29 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
             self.append_keys(**keys)
         else:
             log_keys = {**self._default_log_keys, **keys}
-            formatter = self.logger_formatter or LambdaPowertoolsFormatter(**log_keys)
+            formatter = self.logger_formatter or LambdaPowertoolsFormatter(**log_keys)  # type: ignore
             self.registered_handler.setFormatter(formatter)
 
-    def set_correlation_id(self, value: str):
+    def set_correlation_id(self, value: Optional[str]):
         """Sets the correlation_id in the logging json
 
         Parameters
         ----------
-        value : str
-            Value for the correlation id
+        value : str, optional
+            Value for the correlation id. None will remove the correlation_id
         """
         self.append_keys(correlation_id=value)
 
+    def get_correlation_id(self) -> Optional[str]:
+        """Gets the correlation_id in the logging json
+
+        Returns
+        -------
+        str, optional
+            Value for the correlation id
+        """
+        return self.registered_formatter.log_format.get("correlation_id")
+
     @staticmethod
     def _get_log_level(level: Union[str, int, None]) -> Union[str, int]:
         """Returns preferred log level set by the customer in upper case"""
@@ -421,7 +431,9 @@ class Logger(logging.Logger):  # lgtm [py/missing-call-to-init]
 
 
 def set_package_logger(
-    level: Union[str, int] = logging.DEBUG, stream: sys.stdout = None, formatter: logging.Formatter = None
+    level: Union[str, int] = logging.DEBUG,
+    stream: Optional[IO[str]] = None,
+    formatter: Optional[logging.Formatter] = None,
 ):
     """Set an additional stream handler, formatter, and log level for aws_lambda_powertools package logger.
 
